---
name: Documentation request
about: Ask for clarification in documentation
labels: documentation
---

<!--
Welcome! Before creating a new issue:
* Search for relevant issues
* Follow the issue reporting guidelines:
https://jupyterlab.readthedocs.io/en/latest/getting_started/issue.html
-->

## What I am trying to do...

<!-- Describe what you are trying to do, and how the current docs aren't helping you achieve it-->

## How I would like to learn how to do it...

<!--Describe what would help you understand what you are trying to do, e.g. tutorials, code comments, screencasts, etc.-->

## How the project might keep the docs accurate...

<!--Describe how this documentation can be kept up-to-date: testing, link checking, etc. -->
